@@ -1,12 +1,16 @@
-`crosses` <- function(a,b)duplicated(
+.crosses <- function(a, b, fromLast = FALSE)duplicated(
+	fromLast=fromLast,
 	cbind(
 		as.data.frame(a),
 		as.data.frame(b)
 	)
 )!=
 duplicated(
+	fromLast=fromLast,
 	as.data.frame(a)
 )
+
+`crosses` <- function(a,b,all=FALSE)if(all) .crosses(a,b,FALSE) | .crosses(a,b,TRUE) else .crosses(a,b,FALSE)
 `%crosses%` <- function(a,b)any(crosses(a,b))
 `%crossed.on%` <- function(a,b)b %crosses% a
 `%nests%` <- function(a,b)!b %crosses% a
